<img alt="Logo" height="170" src="https://fkon.frisokar.com.br/icons/fkgrupo.svg" width="170"/>


# fk-utils

[![version](https://img.shields.io/badge/version-0.1.12-purple.svg)](https://semver.org)

Pacotes de utilitários RPA FK Grupo

## Dependências

- Python 3.x
- Poetry ^1.8.3


## Instalação

Com o python instalado, execute os seguintes comandos para instalar as dependências e ativar o ambiente virtual

```bash
  # Instalação do gerenciador de dependencias e ambiente virtual
  pip install poetry
```

```bash
  # Criação do ambiente virtual
  poetry install
```

```bash
  # Ativação do ambiente virtual
  poetry shell
```

## Stack utilizada

**Linguagem de programação:** Python


## Suporte

Para suporte, mande um email para rrzavan@fkgrupo.com


## Autores

- [@rrzavan](https://github.com/rrzavan)

